( cd usr/bin ; rm -rf qalculate )
( cd usr/bin ; ln -sf qalculate-kde qalculate )
( cd usr/share/doc/HTML/en/qalculate_kde ; rm -rf common )
( cd usr/share/doc/HTML/en/qalculate_kde ; ln -sf /usr/share/doc/HTML/en/common common )
