<!DOCTYPE kpartgui>
<kpartgui name="kqalculate">
	<MenuBar>
		<Menu name="file"><text>&amp;File</text>
			<Menu name="new" icon="filenew"><text>&amp;New</text>
				<Action name="new_variable"/>
				<Action name="new_matrix"/>
				<Action name="new_vector"/>
				<Action name="new_unknown_variable"/>
				<Action name="new_function"/>
				<Action name="new_data_set"/>
				<Action name="new_unit"/>
			</Menu>
			<Action name="import_csv_file"/>
			<Action name="export_csv_file"/>
			<Action name="store_result"/>
			<Action name="save_as_image"/>
			<Separator/>
			<Action name="save_definitions"/>
			<Action name="update_exchange_rates"/>
			<Separator/>
			<Action name="plot_functions_data"/>
			<Action name="convert_number_bases"/>
			<Action name="periodic_table"/>
			<Separator/>
			<Action name="quit"/>
		</Menu>
		<Menu name="edit"><text>&amp;Edit</text>
			<Action name="manage_variables"/>
			<Action name="manage_functions"/>
			<Action name="manage_units"/>
			<Action name="manage_data_sets"/>
			<Separator/>
			<Action name="factorize"/>
			<Action name="simplify"/>
			<Action name="set_unknowns"/>
			<Menu name="set_prefix"><text>&amp;Set Prefix</text>
			</Menu>
			<Menu name="convert_to_unit"><text>&amp;Convert To Unit</text>
			</Menu>
			<Action name="convert_to_unit_expression"/>
			<Action name="convert_to_base_units"/>
			<Action name="convert_to_best_unit"/>
			<Separator/>
			<Action name="insert_matrix"/>
			<Action name="insert_vector"/>
			<Separator/>
			<Action name="copy_result"/>
			<Separator/>
			<Action name="preferences"/>
			<Action name="keybindings"/>
			<Action name="configure_global_shortcuts"/>
		</Menu>
		<Menu name="mode"><text>&amp;Mode</text>
			<Menu name="number_base"><text>Number Base</text>
				<Action name="set_base"/>
				<Separator/>
				<Action name="number_base_binary"/>
				<Action name="number_base_octal"/>
				<Action name="number_base_decimal"/>
				<Action name="number_base_hexadecimal"/>
				<Action name="number_base_sexagesimal"/>
				<Action name="number_base_time_format"/>
				<Action name="number_base_roman_numerals"/>				
				<Action name="number_base_other"/>				
			</Menu>
			<Menu name="numerical_display"><text>Numerical Display</text>
				<Action name="numerical_display_normal"/>
				<Action name="numerical_display_engineering"/>
				<Action name="numerical_display_scientific"/>
				<Action name="numerical_display_purely_scientific"/>
				<Action name="numerical_display_simple"/>
				<Separator/>
				<Action name="indicate_infinite_series"/>
				<Action name="show_ending_zeroes"/>
				<Action name="round_halfway_numbers_to_even"/>
				<Action name="negative_exponents"/>
				<Action name="sort_minus_last"/>
			</Menu>
			<Menu name="fractional_display"><text>Fractional Display</text>
				<Action name="fractional_display_decimal"/>
				<Action name="fractional_display_decimal_try_exact"/>
				<Action name="fractional_display_fraction"/>
				<Action name="fractional_display_combined"/>
			</Menu>
			<Menu name="unit_display"><text>Unit Display</text>
				<Action name="enable_prefixes"/>
				<Action name="enable_use_of_all_prefixes"/>
				<Action name="enable_denominator_prefixes"/>
				<Action name="place_units_separately"/>
				<Separator/>
				<Action name="auto_no_conversion"/>
				<Action name="auto_convert_to_base_units"/>
				<Action name="auto_convert_to_best_unit"/>
			</Menu>
			<Menu name="angle_unit"><text>Angle Unit</text>
				<Action name="angle_unit_degrees"/>
				<Action name="angle_unit_radians"/>
				<Action name="angle_unit_gradians"/>
				<Action name="angle_unit_none"/>
			</Menu>
			<Action name="abbreviate_names"/>
			<Separator/>
			<Menu name="enabled_objects"><text>Enabled Objects</text>
				<Action name="enable_variables"/>
				<Action name="enable_functions"/>
				<Action name="enable_units"/>
				<Action name="enable_unknowns"/>
				<Separator/>
				<Action name="calculate_variables"/>
				<Separator/>
				<Action name="allow_complex_result"/>
				<Action name="allow_infinite_result"/>
			</Menu>
			<Separator/>
			<Menu name="approximation"><text>Approximation</text>
				<Action name="approximation_try_exact"/>
				<Action name="approximation_always_exact"/>
				<Action name="approximation_approximate"/>
			</Menu>
			<Menu name="assumptions"><text>Assumptions</text>
				<Action name="assumption_type_unknown"/>
				<Action name="assumption_type_nonmatrix"/>
				<Action name="assumption_type_number"/>
				<Action name="assumption_type_complex"/>
				<Action name="assumption_type_real"/>
				<Action name="assumption_type_rational"/>
				<Action name="assumption_type_integer"/>
				<Separator/>
				<Action name="assumption_sign_unknown"/>
				<Action name="assumption_sign_non_zero"/>
				<Action name="assumption_sign_positive"/>
				<Action name="assumption_sign_non_negative"/>
				<Action name="assumption_sign_negative"/>
				<Action name="assumption_sign_non_positive"/>
			</Menu>
			<Menu name="algebraic_mode"><text>Algebraic Mode</text>
				<Action name="algebraic_mode_simplify"/>
				<Action name="algebraic_mode_factorize"/>
				<Action name="algebraic_mode_none"/>
				<Separator/>
				<Action name="non_zero_denominators"/>
				<Action name="warn_about_denominators_assumed_nonzero"/>
			</Menu>
			<Separator/>
			<Action name="read_precision"/>
			<Action name="limit_implicit_multiplication"/>
			<Action name="rpn_mode"/>
			<Action name="rpn_syntax"/>
			<Separator/>
			<Action name="precision"/>
			<Action name="decimals"/>
			<Separator/>
			<Menu name="modes"><text>Meta Modes</text>
				<Separator/>
				<Action name="save_mode_as"/>
				<Action name="delete_mode"/>
			</Menu>
			<Action name="save_mode"/>
		</Menu>
		<Menu name="functions"><text>Fu&amp;nctions</text>
		</Menu>
		<Menu name="variables"><text>&amp;Variables</text>
		</Menu>
		<Menu name="units"><text>&amp;Units</text>
		</Menu>
	</MenuBar>
</kpartgui>